pub fn cert_payload(version: &str, public_key_hex: &str) -> StringExpand description
The certificate payload the master key signs to bless a per-version public key. Binding the version in means a cert can’t be reused to vouch for a key under a different (e.g. un-revoked) version.